@@ -95,19 +95,8 @@ const ModStruct bomb_description =
 
 #define MAX_DELAY       1000000	/* Max delay between updates */
 #define NAP_TIME        5	/* Sleep between shutdown attempts */
-#define DELTA           10	/* Border around the digits */
 #define RIVET_RADIUS    6	/* Size of detonator 'rivets' */
 
-#ifdef USE_MB
-#define free_font(d) if (mode_font!=None){XFreeFontSet(d,mode_font); \
-mode_font = None;}
-#else
-#define free_font(d) if (mode_font!=None){XFreeFont(d,mode_font); \
-mode_font = None;}
-#endif
-
-extern XFontStruct *getFont(Display * display);
-
 typedef struct {
 	Bool        painted;
 	int         width, height;
@@ -121,41 +110,80 @@ typedef struct {
 	int         text_ascent;
 	int         text_descent;
 	int         moveok;
+	GC          gc;
 } bombstruct;
 
 static bombstruct *bombs = NULL;
 
 #ifdef USE_MB
 static XFontSet mode_font = None;
+static int getFontHeight(XFontSet f)
+{
+	XRectangle ink, log;
+
+	if (f == None) {
+		return 8;
+	} else {
+		XmbTextExtents(mode_font, "My", strlen("My"), &ink, &log);
+		return log.height;
+	}
+}
+static int getTextWidth(char *string)
+{
+	XRectangle ink, logical;
+
+       XmbTextExtents(mode_font, string, strlen(string), &ink, &logical);
+	return logical.width;
+}
+extern XFontSet getFontSet(Display * display);
+#define DrawString(d, p, gc, start, ascent, string, len) (void) XmbDrawString(\
+	d, p, mode_font, gc, start, ascent, string, len)
 #else
 static XFontStruct *mode_font = None;
+#define getFontHeight(f) ((f == None) ? 8 : f->ascent + f->descent)
+static int getTextWidth(char *string)
+{
+	return XTextWidth(mode_font, string, strlen(string));
+}
+extern XFontStruct *getFont(Display * display);
+#define DrawString(d, p, gc, start, ascent, string, len) (void) XDrawString(\
+	d, p, gc, start, ascent, string, len)
 #endif
 
+static void
+free_bomb(Display *display, bombstruct *bp)
+{
+	if (bp->gc != None) {
+		XFreeGC(display, bp->gc);
+		bp->gc = None;
+	}
+}
+
 static void
 rivet(ModeInfo * mi, int x, int y)
 {
-	Display    *display = MI_DISPLAY(mi);
-	GC          gc = MI_GC(mi);
+	Display *display = MI_DISPLAY(mi);
+	GC gc = MI_GC(mi);
 
 	XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 	if (MI_NPIXELS(mi) > 2) {
 		XDrawArc(display, MI_WINDOW(mi), gc, x, y,
-		      2 * RIVET_RADIUS, 2 * RIVET_RADIUS, 270 * 64, 90 * 64);
+			2 * RIVET_RADIUS, 2 * RIVET_RADIUS, 270 * 64, 90 * 64);
 		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 		XDrawArc(display, MI_WINDOW(mi), gc, x, y,
-		      2 * RIVET_RADIUS, 2 * RIVET_RADIUS, 70 * 64, 130 * 64);
+			2 * RIVET_RADIUS, 2 * RIVET_RADIUS, 70 * 64, 130 * 64);
 	} else
 		XDrawArc(display, MI_WINDOW(mi), gc, x, y,
-			 2 * RIVET_RADIUS, 2 * RIVET_RADIUS, 0, 360 * 64);
+			2 * RIVET_RADIUS, 2 * RIVET_RADIUS, 0, 360 * 64);
 }
 
 static void
 detonator(ModeInfo * mi, int draw)
 {
-	Display    *display = MI_DISPLAY(mi);
-	GC          gc = MI_GC(mi);
+	Display *display = MI_DISPLAY(mi);
+	GC gc = MI_GC(mi);
 	bombstruct *bp = &bombs[MI_SCREEN(mi)];
-	int         b_width, b_height;
+	int b_width, b_height;
 
 	b_width = bp->width / 2;
 	b_height = bp->height / 3;
@@ -167,17 +195,17 @@ detonator(ModeInfo * mi, int draw)
 		 */
 		XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_BLACK_PIXEL(mi));
 		XFillRectangle(display, MI_WINDOW(mi), gc,
-			       bp->loc.x, bp->loc.y, b_width, b_height);
+			bp->loc.x, bp->loc.y, b_width, b_height);
 #endif
 		if (MI_NPIXELS(mi) > 2)
 			XSetForeground(MI_DISPLAY(mi), MI_GC(mi),
-				       MI_PIXEL(mi, bp->color));
+				MI_PIXEL(mi, bp->color));
 		else
 			XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_WHITE_PIXEL(mi));
 		/*XSetForeground(display, gc, allocPixel(display, MI_COLORMAP(mi),
-		   "grey", "white")); */
+			"grey", "white")); */
 		XFillRectangle(display, MI_WINDOW(mi), gc,
-			       bp->loc.x, bp->loc.y, b_width, b_height);
+			bp->loc.x, bp->loc.y, b_width, b_height);
 
 		/*
 		 *  If a full size screen (and colour),
@@ -186,16 +214,16 @@ detonator(ModeInfo * mi, int draw)
 		if (bp->width > 160 && bp->height > 160) {
 			rivet(mi, bp->loc.x + RIVET_RADIUS, bp->loc.y + RIVET_RADIUS);
 			rivet(mi, bp->loc.x + RIVET_RADIUS,
-			      bp->loc.y + b_height - 3 * RIVET_RADIUS);
+				bp->loc.y + b_height - 3 * RIVET_RADIUS);
 			rivet(mi, bp->loc.x + b_width - 3 * RIVET_RADIUS,
-			      bp->loc.y + RIVET_RADIUS);
+				bp->loc.y + RIVET_RADIUS);
 			rivet(mi, bp->loc.x + b_width - 3 * RIVET_RADIUS,
-			      bp->loc.y + b_height - 3 * RIVET_RADIUS);
+				bp->loc.y + b_height - 3 * RIVET_RADIUS);
 		}
 	} else {
 		XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_BLACK_PIXEL(mi));
 		XFillRectangle(display, MI_WINDOW(mi), gc,
-			       bp->loc.x, bp->loc.y, b_width, b_height);
+			bp->loc.x, bp->loc.y, b_width, b_height);
 	}
 }
 
@@ -203,19 +231,30 @@ void
 release_bomb(ModeInfo * mi)
 {
 	if (bombs != NULL) {
+		int screen;
+
+		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
+                        free_bomb(MI_DISPLAY(mi), &bombs[screen]);
 		free(bombs);
 		bombs = (bombstruct *) NULL;
 	}
-	free_font(MI_DISPLAY(mi));
+	if (mode_font != None) {
+#ifdef USE_MB
+		XFreeFontSet(MI_DISPLAY(mi), mode_font);
+#else
+		XFreeFont(MI_DISPLAY(mi), mode_font);
+#endif
+		mode_font = None;
+	}
 }
 
 void
 init_bomb(ModeInfo * mi)
 {
-	Display    *display = MI_DISPLAY(mi);
-	GC          gc = MI_GC(mi);
+	Display *display = MI_DISPLAY(mi);
 	bombstruct *bp;
-	char        number[NDIGITS + 2];
+	char number[NDIGITS + 2];
+	XGCValues gcv;
 #ifdef USE_MB
 	char **miss, *def;
 	int n_miss;
@@ -224,7 +263,7 @@ init_bomb(ModeInfo * mi)
 
 	if (bombs == NULL) {
 		if ((bombs = (bombstruct *) calloc(MI_NUM_SCREENS(mi),
-					       sizeof (bombstruct))) == NULL)
+				sizeof (bombstruct))) == NULL)
 			return;
 	}
 	bp = &bombs[MI_SCREEN(mi)];
@@ -232,6 +271,7 @@ init_bomb(ModeInfo * mi)
 	bp->width = MI_WIDTH(mi);
 	bp->height = MI_HEIGHT(mi);
 
+	free_bomb(display, bp);
 	if (mode_font != None) {
 #ifdef USE_MB
 		XFreeFontSet(display, mode_font);
@@ -247,14 +287,14 @@ init_bomb(ModeInfo * mi)
 #else
 		mode_font = XLoadQueryFont(display, FULL_COUNT_FONT);
 #endif
-		bp->delta = DELTA;
+		bp->delta = getTextWidth ((char *) "I");
 	} else {		/* icon window */
 #ifdef USE_MB
 		mode_font = XCreateFontSet(display, ICON_COUNT_FONT, &miss, &n_miss, &def);
 #else
 		mode_font = XLoadQueryFont(display, ICON_COUNT_FONT);
 #endif
-		bp->delta = 2;
+		bp->delta = getTextWidth ((char *) "I");
 	}
 	if (mode_font == None) {
 #ifdef USE_MB
@@ -267,10 +307,24 @@ init_bomb(ModeInfo * mi)
 		release_bomb(mi);
 		return;
 	}
+	if (bp->gc == None && mode_font != None) {
 #ifndef USE_MB
-	XSetFont(display, gc, mode_font->fid);
+		gcv.font = mode_font->fid;
 #endif
-
+		gcv.background = MI_BLACK_PIXEL(mi);
+		gcv.foreground = MI_WHITE_PIXEL(mi);
+		gcv.graphics_exposures = False;
+		if ((bp->gc = XCreateGC(display, MI_WINDOW(mi),
+			GCForeground | GCBackground | GCGraphicsExposures
+#ifndef USE_MB
+			| GCFont
+#endif
+			, &gcv)) == None) {
+			
+			free_bomb(display, bp);
+			return;
+		}
+	}
 #ifdef SIMPLE_COUNTDOWN
 	(void) sprintf(number, "%0*d", NDIGITS, 0);
 #else
@@ -329,13 +383,12 @@ init_bomb(ModeInfo * mi)
 }
 
 extern void logoutUser(Display * display);
-#ifdef SunCplusplus
-/* #include <signal.h> */
-extern int  kill(pid_t, int);
-#else
+#ifdef SOLARIS2
+#include <signal.h>
+#endif
 #if 0
 extern int  kill(int, int);
-#endif
+extern int  kill(pid_t, int);
 #endif
 
 /*
@@ -345,7 +398,7 @@ static void
 explode(ModeInfo * mi)
 {
 	bombstruct *bp = &bombs[MI_SCREEN(mi)];
-	char        buff[NDIGITS + 2];
+	char buff[NDIGITS + 2];
 
 	/*
 	 *  ToDo:
@@ -367,12 +420,12 @@ explode(ModeInfo * mi)
 #endif
 	XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_PIXEL(mi, 1));
 	(void) XDrawString(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-			   bp->x, bp->y, buff, NDIGITS);
+		bp->x, bp->y, buff, NDIGITS);
 
 	(void) fprintf(stderr, "BOOM!!!!\n");
 #ifndef DEBUG
 	if (MI_IS_INWINDOW(mi) || MI_IS_INROOT(mi) ||
-	    MI_IS_NOLOCK(mi) || MI_IS_DEBUG(mi))
+			MI_IS_NOLOCK(mi) || MI_IS_DEBUG(mi))
 		(void) kill((int) getpid(), SIGTERM);
 	else if ((int) getuid() == 0) {		/* Do not try to logout root! */
 		bp->countdown = 0;
@@ -387,11 +440,11 @@ explode(ModeInfo * mi)
 void
 draw_bomb(ModeInfo * mi)
 {
-	Display    *display = MI_DISPLAY(mi);
-	GC          gc = MI_GC(mi);
-	char        number[NDIGITS + 2];
+	Display *display = MI_DISPLAY(mi);
+	GC gc = MI_GC(mi);
+	char number[NDIGITS + 2];
 	unsigned long crayon;
-	int         countleft;
+	int countleft;
 	bombstruct *bp;
 
 	if (bombs == NULL)
@@ -409,16 +462,16 @@ draw_bomb(ModeInfo * mi)
 		(void) sprintf(number, "%0*d", NDIGITS, countleft);
 #else
 		(void) sprintf(number, "%0*d:%02d", NDIGITS - 2,
-			       countleft / 60, countleft % 60);
+			countleft / 60, countleft % 60);
 #endif
 
 		/* Blank out the previous number .... */
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		XFillRectangle(display, MI_WINDOW(mi), gc,
-			       bp->x - bp->delta,
-			       (bp->y - bp->text_ascent) - bp->delta,
-			       bp->text_width + (2 * bp->delta),
-		     (bp->text_ascent + bp->text_descent) + (2 * bp->delta));
+			bp->x - bp->delta,
+			(bp->y - bp->text_ascent) - bp->delta,
+			bp->text_width + (2 * bp->delta),
+			(bp->text_ascent + bp->text_descent) + (2 * bp->delta));
 
 		/* ... and count down */
 		if (MI_NPIXELS(mi) <= 2)
@@ -434,7 +487,8 @@ draw_bomb(ModeInfo * mi)
 				detonator(mi, 0);
 				bp->loc.x = NRAND(bp->width / 2);
 				bp->loc.y = NRAND(bp->height * 3 / 5);
-				bp->x = bp->loc.x + bp->width / 4 - (bp->text_width / 2);
+				bp->x = bp->loc.x + bp->width / 4 -
+					(bp->text_width / 2);
 				bp->y = bp->loc.y + bp->height / 5;	/* Central-ish */
 				if (MI_NPIXELS(mi) > 2)
 					bp->color = NRAND(MI_NPIXELS(mi));
@@ -444,14 +498,10 @@ draw_bomb(ModeInfo * mi)
 		} else {
 			bp->moveok = 1;
 		}
-		XSetForeground(display, gc, crayon);
-#ifndef USE_MB
-		(void) XDrawString(display, MI_WINDOW(mi), gc, bp->x, bp->y,
-				   number, strlen(number));
-#else
-		(void) XmbDrawString(display, MI_WINDOW(mi), mode_font, gc, bp->x, bp->y,
-							 number, strlen(number));
-#endif
+		XSetForeground(display, bp->gc, crayon);
+		DrawString(display, MI_WINDOW(mi), bp->gc,
+			bp->x - getTextWidth((char *) "I") / 2, bp->y,
+			number, strlen(number));
 	}
 }
 
