@@ -30,7 +30,7 @@ static const char sccsid[] = "@(#)swim.c	1.4 2000/01/28 xlockmore";
  * Thanks goes also to Brian Paul for making it possible and inexpensive
  * to use OpenGL at home.
  *
- * My e-mail address is lassauge@mail.dotcom.fr
+ * My e-mail address is lassauge AT users.sourceforge.net
  *
  * Eric Lassauge  (May-13-1998)
  *
@@ -74,6 +74,7 @@ static const char sccsid[] = "@(#)swim.c	1.4 2000/01/28 xlockmore";
  */
 
 #ifdef STANDALONE
+#define MODE_atlantis
 #include "xlockmoreI.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
