@@ -84,8 +84,8 @@ static struct {
 	unsigned dirvec[4];
         unsigned ndirs;
 	unsigned simular_to;
-} tiles[TILES_COUNT] = { 
-/*   
+} tiles[TILES_COUNT] = {
+/*
  *   ' ' == dont care == BLOCK_EMPTY
  *   '#' == set wall, and not clear == BLOCK_WALL
  *   '`' == clear == BLOCK_DOT_1
@@ -95,44 +95,44 @@ static struct {
 	"  #  "
 	" ``` "
 	"  #  "
-	"  #  ", 
+	"  #  ",
         { GO_LEFT, GO_RIGHT, 0, 0 }, 2,
-	(unsigned) (1 << 0 | 1 << 6 | 1 << 8 | 1 << 10) },
+	(unsigned) ((1 << 0) | (1 << 6) | (1 << 8) | (1 << 10)) },
   {     "     "
 	"  `  "
 	"##`##"
 	"  `  "
-	"     ", 
+	"     ",
         { GO_UP, GO_DOWN, 0, 0 }, 2,
-	(unsigned) (1 << 1 | 1 << 7 | 1 << 9 | 1 << 10) },
+	(unsigned) ((1 << 1) | (1 << 7) | (1 << 9) | (1 << 10)) },
   { 	"   ##"
 	"##`##"
 	"##`` "
 	"#### "
-	"#### ", 
+	"#### ",
         { GO_UP, GO_RIGHT, 0, 0 }, 2,
-	(unsigned) (1 << 2 | 1 << 6 | 1 << 7 | 1 << 10) },
+	(unsigned) ((1 << 2) | (1 << 6) | (1 << 7) | (1 << 10)) },
   {	"#### "
 	"#### "
 	"##`` "
 	"##`##"
-	"   ##", 
+	"   ##",
         { GO_RIGHT, GO_DOWN, 0, 0 }, 2,
-	(unsigned) (1 << 3 | 1 << 7 | 1 << 8 | 1 << 10) },
+	(unsigned) ((1 << 3) | (1 << 7) | (1 << 8) | (1 << 10)) },
   {	"  ###"
 	"  ###"
 	" ``##"
 	"##`  "
 	"##   ",
         { GO_LEFT, GO_DOWN, 0, 0 }, 2,
-	(unsigned) (1 << 4 | 1 << 8 | 1 << 9 | 1 << 10) },
+	(unsigned) ((1 << 4) | (1 << 8) | (1 << 9) | (1 << 10)) },
   {	"##   "
 	"##`##"
 	" ``##"
 	" ####"
 	" ####",
         { GO_LEFT, GO_UP, 0, 0 }, 2,
-	(unsigned) (1 << 5 | 1 << 6 | 1 << 9 | 1 << 10) },
+	(unsigned) ((1 << 5) | (1 << 6) | (1 << 9) | (1 << 10)) },
   {	"##`##"
 	"##`##"
 	"`````"
@@ -152,7 +152,7 @@ static struct {
         "`````"
         "##`##"
         "##`##",
-        { GO_LEFT, GO_RIGHT, GO_DOWN, 0}, 3, 
+        { GO_LEFT, GO_RIGHT, GO_DOWN, 0}, 3,
 	(unsigned) (1 << 8) },
   {	"##`  "
         "##`##"
@@ -176,28 +176,28 @@ static const unsigned tileprob[MAXTILEPROB] =
 	{ 0, 0, 0, 1, 1, 2, 3, 4, 5, 6, 6, 6, 7, 7, 8, 8, 8, 9, 9, 10, 10, 10 };
 
 /* Sets a block in the level to a certain state. */
-static void 
-setblockto(lev_t *level, const unsigned x, const unsigned y, 
-		const char c) 
+static void
+setblockto(lev_t *level, const unsigned x, const unsigned y,
+		const char c)
 {
 	if (!(x < LEVWIDTH && y < LEVHEIGHT)) return;
 	(*level)[y][x] = c;
 }
 
 /* check if a block is set */
-static int 
-checkset(lev_t *level, const unsigned x, const unsigned y) 
+static int
+checkset(lev_t *level, const unsigned x, const unsigned y)
 {
 	if (!(x < LEVWIDTH && y < LEVHEIGHT) ||
-			(*level)[y][x] == BLOCK_WALL || 
+			(*level)[y][x] == BLOCK_WALL ||
 			(*level)[y][x] == BLOCK_GHOST_ONLY)
 		return True;
 	return False;
 }
 
 /* Check if a block is not set */
-static int 
-checksetout(lev_t *level, const unsigned x, const unsigned y) 
+static int
+checksetout(lev_t *level, const unsigned x, const unsigned y)
 {
 	if (!(x < LEVWIDTH && y < LEVHEIGHT) ||
 			checkset(level, x, y) != 0)
@@ -207,8 +207,8 @@ checksetout(lev_t *level, const unsigned x, const unsigned y)
 }
 
 /* Check if a block cannot be set */
-static int 
-checkunsetdef(lev_t *level, const unsigned x, const unsigned y) 
+static int
+checkunsetdef(lev_t *level, const unsigned x, const unsigned y)
 {
 	if (!(x < LEVWIDTH && y < LEVHEIGHT))
 		return False;
@@ -217,8 +217,8 @@ checkunsetdef(lev_t *level, const unsigned x, const unsigned y)
 }
 
 /* Initializes a level to empty state. */
-static void 
-clearlevel(lev_t *level) 
+static void
+clearlevel(lev_t *level)
 {
         unsigned x, y;
 
@@ -230,7 +230,7 @@ clearlevel(lev_t *level)
 /* Changes a level from the level creation structure ((array to array) to
    array. */
 static void
-copylevel(char *dest, lev_t *level) 
+copylevel(char *dest, lev_t *level)
 {
 	unsigned x, y;
 
@@ -240,9 +240,9 @@ copylevel(char *dest, lev_t *level)
 }
 
 /* Creates a jail to work around, so we can finish it later. */
-static void 
-createjail(lev_t *level, const unsigned width, 
-		const unsigned height) 
+static void
+createjail(lev_t *level, const unsigned width,
+		const unsigned height)
 {
         unsigned x, y, xstart, xend, ystart, yend;
 
@@ -263,9 +263,9 @@ createjail(lev_t *level, const unsigned width,
 }
 
 /* Finishes a jail so it is empty and the ghostpass is on top. */
-static void 
-finishjail(lev_t *level, const unsigned width, 
-		const unsigned height) 
+static void
+finishjail(lev_t *level, const unsigned width,
+		const unsigned height)
 {
         unsigned x, y, xstart, xend, ystart, yend;
 
@@ -295,9 +295,9 @@ finishjail(lev_t *level, const unsigned width,
 /* Tries to set a block at a certain position. Returns true if possible,
     and leaves level in new state (plus block), or False if not possible,
     and leaves level in unpredictable state. */
-static int 
-tryset(lev_t *level, const unsigned xpos, const unsigned ypos, 
-		const char *block) 
+static int
+tryset(lev_t *level, const unsigned xpos, const unsigned ypos,
+		const char *block)
 {
         register unsigned x, y;
         register char locchar;
@@ -326,30 +326,30 @@ tryset(lev_t *level, const unsigned xpos, const unsigned ypos,
                                  xstart + x < LEVWIDTH &&
                                  ystart + y > 1 &&
                                  ystart + y < LEVHEIGHT - 1) &&
-                                 checkunsetdef(level, 
-					 (unsigned)(xstart + x), 
+                                 checkunsetdef(level,
+					 (unsigned)(xstart + x),
 					 (unsigned)(ystart + y)) != 0)
                                 return False;
                 }
 
         /* and set the block in place */
 
-        xend = (xstart + TILEWIDTH < LEVWIDTH - 1) ? 
+        xend = (xstart + TILEWIDTH < LEVWIDTH - 1) ?
                 TILEWIDTH : LEVWIDTH - xstart - 2;
         yend = (ystart + TILEHEIGHT < LEVHEIGHT - 1) ?
                 TILEHEIGHT : LEVHEIGHT - ystart - 2;
 
-        for (y = (ystart < 1) ? (unsigned)(1 - ystart) : 0U ; 
+        for (y = (ystart < 1) ? (unsigned)(1 - ystart) : 0U ;
                         y < yend ; y++)
-                for (x = (xstart < 1) ? 
-				(unsigned)(1 - xstart) : 0U ; 
+                for (x = (xstart < 1) ?
+				(unsigned)(1 - xstart) : 0U ;
 		       x < xend ; x++) {
                         locchar = block[y * TILEWIDTH + x];
 			if ((locchar == BLOCK_WALL) &&
                             ((*level)[ystart + y][xstart + x] == BLOCK_EMPTY)) {
                                 (*level)[ystart + y][xstart + x] = BLOCK_WALL;
                                 (*level)[ystart + y]
-					[LEVWIDTH - (xstart + x + 1)] = 
+					[LEVWIDTH - (xstart + x + 1)] =
 						BLOCK_WALL;
                         }
                 }
@@ -362,8 +362,8 @@ tryset(lev_t *level, const unsigned xpos, const unsigned ypos,
 
 /* Tries certain combinations of blocks in the level recursively. */
 static unsigned
-nextstep(lev_t *level, const unsigned x, const unsigned y, 
-		unsigned dirvec[], unsigned ndirs) 
+nextstep(lev_t *level, const unsigned x, const unsigned y,
+		unsigned dirvec[], unsigned ndirs)
 {
         unsigned dirpos, curdir, inc = 0;
 	int ret = 0;
@@ -383,13 +383,13 @@ nextstep(lev_t *level, const unsigned x, const unsigned y,
 
                 switch (curdir) {
                    case GO_UP:
-                        if (y < 1 || 
-                                (ret = creatlevelblock(level, x, y - 1)) 
+                        if (y < 1 ||
+                                (ret = creatlevelblock(level, x, y - 1))
                                         == 0)
                                 return 0;
                         break;
                    case GO_RIGHT:
-                        if (x > LEVWIDTH - 2 || 
+                        if (x > LEVWIDTH - 2 ||
                                 (ret = creatlevelblock(level, x + 1, y))
                                         == 0)
                                 return 0;
@@ -401,7 +401,7 @@ nextstep(lev_t *level, const unsigned x, const unsigned y,
                                 return 0;
                         break;
                    case GO_LEFT:
-                        if (x < 1 || 
+                        if (x < 1 ||
                                 (ret = creatlevelblock(level, x - 1, y))
                                         == 0)
                                 return 0;
@@ -410,11 +410,11 @@ nextstep(lev_t *level, const unsigned x, const unsigned y,
 			inc += (unsigned)ret;
         }
 	if (inc == 0) inc = 1;
-        return inc; 
+        return inc;
 }
 
-static int 
-creatlevelblock(lev_t *level, const unsigned x, const unsigned y) 
+static int
+creatlevelblock(lev_t *level, const unsigned x, const unsigned y)
 {
         unsigned tried = GETNB(TILES_COUNT);
         unsigned tilenr;
@@ -430,20 +430,20 @@ creatlevelblock(lev_t *level, const unsigned x, const unsigned y)
         if (x == 0)
 		tried &= ~(1<<0);
         else if (x == 1)
-		tried &= ~(1<<4 | 1<<5 | 1<<6 | 1<<8 | 1<<9 | 1<<10);
+		tried &= ~((1<<4) | (1<<5) | (1<<6) | (1<<8) | (1<<9) | (1<<10));
         else if (x == LEVWIDTH-1)
 		tried &= ~(1<<0);
         else if (x == LEVWIDTH-2)
-		tried &= ~(1<<2 | 1<<3 | 1<<6 | 1<<7 | 1<<8 | 1<<10);
+		tried &= ~((1<<2) | (1<<3) | (1<<6) | (1<<7) | (1<<8) | (1<<10));
 
-        if (y == 1) 
-		tried &= ~(1<<2 | 1<<5 | 1<<6 | 1<<7 | 1<<9 | 1<<10);
+        if (y == 1)
+		tried &= ~((1<<2) | (1<<5) | (1<<6) | (1<<7) | (1<<9) | (1<<10));
         else if (y == 0)
 		tried &= ~(1<<1);
         else if (y == LEVHEIGHT-1)
 		tried &= ~(1<<1);
         else if (y == LEVHEIGHT-2)
-		tried &= ~(1<<3 | 1<<4 | 1<<7 | 1<<8 | 1<<9 | 1<<10);
+		tried &= ~((1<<3) | (1<<4) | (1<<7) | (1<<8) | (1<<9) | (1<<10));
 
 	/* make a copy of the current level, so we can go back on the stack */
         (void) memcpy(&savedlev, level, sizeof(lev_t));
@@ -468,21 +468,21 @@ creatlevelblock(lev_t *level, const unsigned x, const unsigned y)
 }
 
 /* Fills up all empty space so there is wall everywhere. */
-static void 
-filllevel(lev_t *level) 
+static void
+filllevel(lev_t *level)
 {
         unsigned x, y;
 
         for (y = 0; y < LEVHEIGHT; y++)
                 for (x = 0; x < LEVWIDTH; x++)
-                        if ((*level)[y][x] == BLOCK_EMPTY) 
+                        if ((*level)[y][x] == BLOCK_EMPTY)
 				(*level)[y][x] = BLOCK_WALL;
 }
 
 /* Changes a level from a simple wall/nowall to a wall with rounded corners
    and such.  Stupid algorithm, could be done better! */
-static void 
-frmtlevel(lev_t *level) 
+static void
+frmtlevel(lev_t *level)
 {
         lev_t frmtlev;
         register unsigned x, y;
@@ -500,12 +500,12 @@ frmtlevel(lev_t *level)
                         }
 
 			if ((*level)[y][x] == BLOCK_GHOST_ONLY) {
-				frmtlev[y][x] = BLOCK_GHOST_ONLY;	
+				frmtlev[y][x] = BLOCK_GHOST_ONLY;
 				continue;
 			}
 
-                        poscond = 
-                                 (checksetout(level, x - 1, y - 1) != 0 ? 
+                        poscond =
+                                 (checksetout(level, x - 1, y - 1) != 0 ?
                                          0x01U : 0U) |
                                  (checksetout(level, x + 1, y - 1) != 0 ?
                                          0x02U : 0U) |
@@ -514,7 +514,7 @@ frmtlevel(lev_t *level)
                                  (checksetout(level, x - 1, y + 1) != 0 ?
                                          0x08U : 0U);
 
-                        poscond2 = 
+                        poscond2 =
                                 (checksetout(level, x - 1, y) != 0 ?
                                         0x01U : 0) |
                                 (checksetout(level, x, y - 1) != 0 ?
@@ -607,7 +607,7 @@ createnewlevel(ModeInfo * mi)
 			clearlevel(level);
 			createjail(level, JAILWIDTH, JAILHEIGHT);
 			if ((ret = nextstep(level, LEVWIDTH/2 - 1,
-					    LEVHEIGHT/2 - JAILHEIGHT/2 - 3, 
+					    LEVHEIGHT/2 - JAILHEIGHT/2 - 3,
 					    dirvec, 1)) == 0) {
 				(void) free((void *) level);
 				return i;
@@ -631,7 +631,7 @@ createnewlevel(ModeInfo * mi)
 
 /* Checks if a position is allowable for ghosts/pacs to enter. */
 static int
-check_pos(pacmangamestruct *pp, int y, int x, int ghostpass) 
+check_pos(pacmangamestruct *pp, int y, int x, int ghostpass)
 {
 	if ((pp->level[y*LEVWIDTH + x] == BLOCK_DOT_2) ||
 	    (pp->level[y*LEVWIDTH + x] == BLOCK_EMPTY) ||
@@ -642,8 +642,8 @@ check_pos(pacmangamestruct *pp, int y, int x, int ghostpass)
 }
 
 /* Checks if there is a dot on the specified position in the level. */
-static int 
-check_dot(pacmangamestruct *pp, unsigned int x, unsigned int y) 
+static int
+check_dot(pacmangamestruct *pp, unsigned int x, unsigned int y)
 {
 	if (x >= LEVWIDTH || y >= LEVHEIGHT) return 0;
 	if (pp->level[y * LEVWIDTH + x] == BLOCK_DOT_2) return 1;
