@@ -163,6 +163,9 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_invert
 	"invert",
 #endif
+#ifdef MODE_juggler3d
+	"juggler3d",
+#endif
 #ifdef MODE_lament
 	"lament",
 #endif
@@ -348,25 +351,25 @@ static char nice_modes[][MAXMODECHARS] =
 	"kaleid",
 #endif
 #ifdef MODE_life
-  "life",
+	"life",
 #endif
 #ifdef MODE_life1d
-  "life1d",
+	"life1d",
 #endif
 #ifdef MODE_life3d
-  "life3d",
+	"life3d",
 #endif
 #ifdef MODE_lightning
-  "lightning",
+	"lightning",
 #endif
 #ifdef MODE_lisa
-  "lisa",
+	"lisa",
 #endif
 #ifdef MODE_lissie
-  "lissie",
+	"lissie",
 #endif
 #ifdef MODE_loop
-  "loop",
+	"loop",
 #endif
 #ifdef MODE_marquee
 	"marquee",
@@ -945,13 +948,19 @@ parsemodelist(ModeInfo * mi)
 #ifdef WIN32
 extern int showtext;/* from xlock.c */
 extern char* xlock95_get_modelist(void);/* from xlock95.c */
+extern GC GCCreate();
+extern void xlockmore_set_mode_options(ModeSpecOpt *ms);
+extern void XGetGCValues(Display *display, GC gc, unsigned long valuemask,
+    XGCValues* values_return);
 #endif
 
 static void
 setMode(ModeInfo * mi, int newmode)
 {
+#ifndef WIN32
 	randomstruct *rp = &randoms[MI_SCREEN(mi)];
 	int         i;
+#endif
 
 	previousmode = currentmode;
 	currentmode = newmode;
